# Custom Clients for Payme | Payment Service 
Sourcode and Resources for Python & Payme <hr>
Support Telegram - http://t.me/Muhammadalive <br>
Documentation & More https://developer.help.paycom.uz/ru/
<hr>
<img src="https://is4-ssl.mzstatic.com/image/thumb/Purple116/v4/d4/29/14/d429146c-485e-d790-eb8d-1f6fdf2ec1a5/AppIcon-0-0-1x_U007emarketing-0-0-0-8-0-0-sRGB-0-0-0-GLES2_U002c0-512MB-85-220-0-0.png/1200x630wa.png">
